﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Data.SqlClient;
using System.Configuration;

namespace StarFashion
{
    public partial class frmMain : Form
    {
        private bool _isManager = false;

        public frmMain()
        {
            InitializeComponent();
        }

        public frmMain(bool isManager)
        {
            InitializeComponent();
            _isManager = isManager;
        }

        private void exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void aboutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            AboutSF about = new AboutSF();
            about.ShowDialog();
        }

        private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
        {
            DialogResult result = MessageBox.Show("Are you sure you want to exit the application?",
                "Exit StarFashion Application", MessageBoxButtons.YesNo);
            if (result == System.Windows.Forms.DialogResult.No)
                e.Cancel = true;
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            // TODO: This line of code loads data into the 'starFashionDataSet1.ItemType' table. You can move, or remove it, as needed.
            this.itemTypeTableAdapter.Fill(this.starFashionDataSet1.ItemType);
            // TODO: This line of code loads data into the 'starFashionDataSet.Item' table. You can move, or remove it, as needed.
            this.itemTableAdapter.Fill(this.starFashionDataSet.Item);
            this.lblDate.Text = DateTime.Now.ToLongDateString().ToString();
            txtCode.Focus();
        }

        private void fillByToolStripButton_Click(object sender, EventArgs e)
        {
            try
            {
                this.itemTypeTableAdapter.FillBy(this.starFashionDataSet1.ItemType);
            }
            catch (System.Exception ex)
            {
                System.Windows.Forms.MessageBox.Show(ex.Message, "StarFashion");
            }

        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            ClearInputControls();
        }

        private void ClearInputControls()
        {
            txtBrandName.Text = "";
            txtCode.Text = "";
            txtColor.Text = "";
            txtCost.Text = "";
            txtDescription.Text = "";
            txtSize.Text = "";
            cmbItemName.SelectedIndex = 0;
            dtInventoried.Value = DateTime.Now;
        }

        private bool IsCodeValid()
        {
            return txtCode.Text.Length > 0;
        }

        private bool IsBrandNameValid()
        {
            return txtBrandName.Text.Length > 0;
        }

        private bool IsItemNameValid()
        {
            return cmbItemName.SelectedIndex > 0;
        }

        private bool IsSizeValid()
        {
            return txtSize.Text.Length > 0;
        }

        private bool IsColorValid()
        {
            return txtColor.Text.Length > 0;
        }

        private bool IsCostValid()
        {
            return txtCost.Text.Length > 0;
        }

        private void txtCode_Validated(object sender, EventArgs e)
        {
            if (!IsCodeValid())
            {
                MessageBox.Show("Please enter a code", "StarFashion");
                txtCode.BackColor = Color.Yellow;
                txtCode.Focus();
            }
            else
            {
                txtCode.BackColor = Color.White;
            }
        }

        private void txtBrandName_Validated(object sender, EventArgs e)
        {
            if (!IsBrandNameValid())
            {
                MessageBox.Show("Please enter a brand name", "StarFashion");
                txtBrandName.BackColor = Color.Yellow;
                txtBrandName.Focus();
            }
            else
            {
                txtBrandName.BackColor = Color.White;
            }
        }

        private void cmbItemName_Validated(object sender, EventArgs e)
        {
            if (!IsItemNameValid())
            {
                MessageBox.Show("Please select an item name", "StarFashion");
                cmbItemName.BackColor = Color.Yellow;
                cmbItemName.Focus();
            }
            else
            {
                cmbItemName.BackColor = Color.White;
            }
        }

        private void txtSize_Validated(object sender, EventArgs e)
        {
            if (!IsSizeValid())
            {
                MessageBox.Show("Please enter a size", "StarFashion");
                txtSize.BackColor = Color.Yellow;
                txtSize.Focus();
            }
            else
            {
                txtSize.BackColor = Color.White;
            }
        }

        private void txtColor_Validated(object sender, EventArgs e)
        {
            if (!IsColorValid())
            {
                MessageBox.Show("Please enter a color", "StarFashion");
                txtColor.BackColor = Color.Yellow;
                txtColor.Focus();
            }
            else
            {
                txtColor.BackColor = Color.White;
            }
        }

        private void txtCost_Validated(object sender, EventArgs e)
        {
            if (!IsCostValid())
            {
                MessageBox.Show("Please enter a cost", "StarFashion");
                txtCost.BackColor = Color.Yellow;
                txtCost.Focus();
            }
            else
            {
                txtCost.BackColor = Color.White;
            }
        }

        private void btnAddItem_Click(object sender, EventArgs e)
        {
            if (IsItemDataValid())
            {
                SqlCommand command;
                string statement = string.Empty;

                try
                {
                    statement = string.Format("insert into Item(Code, BrandName, Size, Color, Description, DateInventoried, TypeId, Cost) " +
                        "values('{0}','{1}','{2}','{3}','{4}','{5}',{6},{7})",
                        txtCode.Text,
                        txtBrandName.Text,
                        txtSize.Text,
                        txtColor.Text,
                        txtDescription.Text,
                        dtInventoried.Value,
                        cmbItemName.SelectedIndex,
                        txtCost.Text);
                    command = new SqlCommand();
                    string connString = ConfigurationManager.ConnectionStrings["StarFashion.Properties.Settings.StarFashionConnectionString"].ConnectionString;
                    command.Connection = new SqlConnection(connString);
                    command.Connection.Open();
                    command.CommandText = statement;
                    int rowsAffected = command.ExecuteNonQuery();
                    if (rowsAffected != 1)
                        MessageBox.Show("Item was not inserted!", "StarFashion");
                    command.Connection.Close();
                    itemTableAdapter.Fill(starFashionDataSet.Item);
                    gridViewMain.Invalidate();
                    gridViewMain.Refresh();
                    MessageBox.Show("The item with code " + txtCost.Text +
                        " was added to the inventory", "StartFashion");

                    ClearInputControls();
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Could not insert the item because of the following exception" +
                        ex.Message, "StarFashion");
                }
            }
            else
            {
                MessageBox.Show("Coud not save data; Make sure all required data is entered!", "StarFashion");
            }
        }

        private bool IsItemDataValid()
        {
            if (txtBrandName.Text != "" &&
                txtCode.Text != "" &&
                txtColor.Text != "" &&
                txtSize.Text != "" &&
                cmbItemName.SelectedIndex > 0)
                return true;
            else
                return false;
        }

        private void btnSearchClear_Click(object sender, EventArgs e)
        {
            
        }

        private void btnSearch_Click(object sender, EventArgs e)
        {
            
        }

        private void txtSearchInventoried_Leave(object sender, EventArgs e)
        {
            
        }

        private void deleteItemToolStripMenuItem_Click(object sender, EventArgs e)
        {
            
        }

        private void DeleteItem(string code)
        {
            
        }

        private void updateItemToolStripMenuItem_Click(object sender, EventArgs e)
        {
            
        }

        private void allItemsToolStripMenuItem_Click(object sender, EventArgs e)
        {
            
        }

        private void todayToolStripMenuItem_Click(object sender, EventArgs e)
        {
            
        }

        private void thisMonthToolStripMenuItem_Click(object sender, EventArgs e)
        {
            
        }

        private void thisYearToolStripMenuItem_Click(object sender, EventArgs e)
        {
            
        }

        private void withDateRangeToolStripMenuItem1_Click(object sender, EventArgs e)
        {
           
        }

        private void cbGenerateId_CheckedChanged(object sender, EventArgs e)
        {
            
        }

        private void toolStripMenuItem1_Click(object sender, EventArgs e)
        {
            
        }

        private void todayToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            
        }

        private void thisMonthToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            
        }

        private void thisYearToolStripMenuItem1_Click(object sender, EventArgs e)
        {
            
        }
    }
}
